@@ -25,7 +25,7 @@ from sklearn.preprocessing import StandardScaler
 from sklearn.svm import SVC, LinearSVC
 
 from . import metrics, get_seed
-from .base import BaseLearner
+from .base import Learner
 from .hpo import find_best_params
 from .metrics import loss_threshold
 
@@ -48,7 +48,7 @@ _overlap_params = {
 }
 
 
-class Classifier(BaseLearner):
+class Classifier(Learner):
     def __init__(self, data: pd.DataFrame, cv=10, labels_col=None):
         super().__init__()
         self.logger = logging.getLogger(__name__)
@@ -181,7 +181,7 @@ class Classifier(BaseLearner):
             self.logger.info(f"Iteration {i + 1}/{n_iter} completed.")
 
             thres = loss_threshold(n_classes=len(self.categories), metric=metric)
-            self.logger.info(f"Mean accuracy on test instances (iteration #{i+1}): {round(accuracy / k, 4)}")
+            self.logger.info(f"Mean accuracy on test instances (iteration #{i + 1}): {round(accuracy / k, 4)}")
             self.logger.debug(f"Proximate conversion of metric '{metric}' to accuracy (mean): "
                               f"{np.mean(score <= thres)}")
 
@@ -218,11 +218,18 @@ class Classifier(BaseLearner):
             if algo_params is None:
                 algo_params = dict()
 
-            result[name], self.predicted_proba[name] = self.run(algo=algo, metric=metric, n_folds=n_folds,
-                                                                n_iter=n_iter, verbose=verbose,
-                                                                hyper_param_optm=hyper_param_optm, hpo_evals=hpo_evals,
-                                                                hpo_timeout=hpo_timeout, hpo_name=name,
-                                                                **algo_params)
+            result[name], self.predicted_proba[name] = self.run(
+                algo=algo,
+                metric=metric,
+                n_folds=n_folds,
+                n_iter=n_iter,
+                hyper_param_optm=hyper_param_optm,
+                hpo_evals=hpo_evals,
+                hpo_timeout=hpo_timeout,
+                hpo_name=name,
+                verbose=verbose,
+                **algo_params
+            )
 
         df_result = pd.DataFrame(result)
 
