@@ -39,7 +39,7 @@ def build_metadata(data: pd.DataFrame, config: Configurations,
     problem = config.general.problem
     target_col = config.general.target_col
     if problem == 'classification':
-        measures = ClassificationMeasures(data, labels_col=target_col)
+        measures = ClassificationMeasures(data, target_col=target_col)
         learners = Classifier(data, labels_col=target_col)
     elif problem == 'regression':
         # measures = ...
@@ -80,6 +80,41 @@ def build_metadata(data: pd.DataFrame, config: Configurations,
         return df_metadata
 
 
+def run_isa(rootdir: Path, metadata: Union[pd.DataFrame, Path] = None, settings: dict = None,
+            save_output: bool = True, rotation_adjust: bool = True, verbose: bool = False):
+    if rotation_adjust is None:
+        rotation_adjust = False
+
+    if not rootdir.exists():
+        raise NotADirectoryError(f"Invalid directory {repr(repr(rootdir))}.")
+
+    opts_path = rootdir / options_file
+    if opts_path.is_file():
+        with open(str(opts_path)) as f:
+            opts = json.load(f)
+    else:
+        raise FileNotFoundError(f"File 'options.json' not found in specified path {repr(str(rootdir))}.")
+
+    meta_path = rootdir / metadata_file
+    if isinstance(metadata, pd.DataFrame):
+        pass
+    elif meta_path.is_file():
+        metadata = pd.read_csv(meta_path, index_col='instances')
+    else:
+        raise FileNotFoundError(f"File 'metadata.csv' not found in specified path {repr(str(rootdir))}.")
+
+    opts = update_options(opts, settings)
+
+    if verbose:
+        logging.getLogger('pyispace').setLevel(logging.DEBUG)
+    else:
+        logging.getLogger('pyispace').setLevel(logging.INFO)
+    out = train_is(metadata, opts, rotation_adjust)
+    if save_output:
+        scriptcsv(out, rootdir)
+    return out
+
+
 def run_matilda(rootdir, matildadir, metadata=None):
     """
     This is a wrapper function to call Matilda Matlab routine via Python.
@@ -112,7 +147,7 @@ def run_matilda(rootdir, matildadir, metadata=None):
         warnings.warn("File {0} not found in '{1}'. "
                       "Building default options file with example script...".format(options_file, rootdir))
 
-    import matlab.engine
+    import matlab.engine  # noqa
     eng = matlab.engine.start_matlab()
     eng.cd(f'{matildadir}{os.sep}', nargout=0)
     eng.trainIS(f'{rootdir}{os.sep}', nargout=0)
@@ -136,37 +171,6 @@ def update_options(d1: dict, d2: dict):
     return d1
 
 
-def run_isa(rootdir: Path, metadata=None, settings=None, save_output=True, rotation_adjust=True):
-    if rotation_adjust is None:
-        rotation_adjust = False
-
-    if not rootdir.exists():
-        raise NotADirectoryError(f"Invalid directory {repr(repr(rootdir))}.")
-
-    opts_path = rootdir / options_file
-    if opts_path.is_file():
-        with open(str(opts_path)) as f:
-            opts = json.load(f)
-    else:
-        raise FileNotFoundError(f"File 'options.json' not found in specified path {repr(str(rootdir))}.")
-
-    meta_path = rootdir / metadata_file
-    if isinstance(metadata, pd.DataFrame):
-        pass
-    elif meta_path.is_file():
-        metadata = pd.read_csv(meta_path, index_col='instances')
-    else:
-        raise FileNotFoundError(f"File 'metadata.csv' not found in specified path {repr(str(rootdir))}.")
-
-    opts = update_options(opts, settings)
-
-    logging.getLogger('pyispace').setLevel(logging.DEBUG)
-    out = train_is(metadata, opts, rotation_adjust)
-    if save_output:
-        scriptcsv(out, rootdir)
-    return out
-
-
 @deprecated(deprecated_in='1.7.4',
             removed_in='2.0.0',
             details="only used in module graphene, which was discontinued")
