@@ -11,7 +11,7 @@ from sklearn.naive_bayes import GaussianNB
 from sklearn.neighbors import NearestNeighbors, DistanceMetric
 
 from . import get_seed
-from .base import BaseMeasures
+from .base import Measures
 
 
 def minmax(f: np.ndarray, y: np.ndarray):
@@ -75,14 +75,14 @@ def gower_distance(X):
     return cumsum_dist
 
 
-class ClassificationMeasures(BaseMeasures):
+class ClassificationMeasures(Measures):
     """
-    Hardness measures class. It provides separate methods to compute each measure
+    Hardness measures for classification. It provides separate methods to compute each measure
 
     :param data: a dataframe where each line is an instace and columns are features. One column should contain the
         labels. The name of the column with labels can be set with parameter `labels_col`
     :type: pandas DataFrame
-    :param labels_col: name of the column that contains the labels of the instances (default None - uses the
+    :param target_col: name of the column that contains the labels of the instances (default None - uses the
         last column)
     :param ccp_alpha: pruning parameter for pruned tree measures. If none is passed, then it attempts to tune it
         automatically
@@ -112,15 +112,15 @@ class ClassificationMeasures(BaseMeasures):
 
     logger = logging.getLogger(__name__)
 
-    def __init__(self, data: pd.DataFrame, ccp_alpha=None, labels_col=None):
-        if labels_col is None:
-            self.labels_col = data.columns[-1]
+    def __init__(self, data: pd.DataFrame, ccp_alpha=None, target_col=None):
+        if target_col is None:
+            self.target_col = data.columns[-1]
             self.y = data.iloc[:, -1]
         else:
-            self.labels_col = labels_col
-            self.y = data[labels_col]
+            self.target_col = target_col
+            self.y = data[target_col]
         self.data = data.reset_index(drop=True)
-        self.X = data.drop(columns=self.labels_col)
+        self.X = data.drop(columns=self.target_col)
         self.N = len(data)
 
         seed = get_seed()
@@ -168,7 +168,7 @@ class ClassificationMeasures(BaseMeasures):
 
         kDN = []
         for i in range(0, len(data)):
-            v = data.loc[indices[i]][self.labels_col].values
+            v = data.loc[indices[i]][self.target_col].values
             kDN.append(np.sum(v[1:] != v[0]) / k)
         return np.array(kDN)
 
@@ -189,7 +189,7 @@ class ClassificationMeasures(BaseMeasures):
         dcp = []
         for index, row in data.iterrows():
             df_leaf = data[data['leaf_id'] == row['leaf_id']]
-            dcp.append(len(df_leaf[df_leaf[self.labels_col] == row[self.labels_col]]) / len(df_leaf))
+            dcp.append(len(df_leaf[df_leaf[self.target_col] == row[self.target_col]]) / len(df_leaf))
 
         return 1 - np.array(dcp)
 
@@ -221,14 +221,14 @@ class ClassificationMeasures(BaseMeasures):
         return (1 - CLD) / 2
 
     def minority_value(self):
-        mv_class = self.data.groupby(self.labels_col).count().iloc[:, 0]
+        mv_class = self.data.groupby(self.target_col).count().iloc[:, 0]
         mv_class = mv_class.divide(mv_class.max())
 
         labels = self.y
         return labels.apply(lambda c: 1 - mv_class[c]).values
 
     def class_balance(self):
-        cb_class = self.data.groupby(self.labels_col).count().iloc[:, 0]
+        cb_class = self.data.groupby(self.target_col).count().iloc[:, 0]
         cb_class = cb_class.divide(self.N) - 1 / len(self.y.unique())
 
         labels = self.y
@@ -347,8 +347,8 @@ class ClassificationMeasures(BaseMeasures):
             sub_df = df[(self.y == p[0]) | (self.y == p[1])]
             indicator = pd.Series(0, index=sub_df.index)
             for f in features:
-                m1 = maxmin(sub_df[f].values, sub_df[self.labels_col].values)
-                m2 = minmax(sub_df[f].values, sub_df[self.labels_col].values)
+                m1 = maxmin(sub_df[f].values, sub_df[self.target_col].values)
+                m2 = minmax(sub_df[f].values, sub_df[self.target_col].values)
                 indicator += sub_df[f].between(m1, m2, inclusive=False) * 1
             F1 = F1.add(indicator.divide(n_features), fill_value=0)
 
@@ -365,8 +365,8 @@ class ClassificationMeasures(BaseMeasures):
         for p in itertools.combinations(classes, 2):
             sub_df = df[(self.y == p[0]) | (self.y == p[1])]
             for f in features:
-                m1 = maxmin(sub_df[f].values, sub_df[self.labels_col].values)
-                m2 = minmax(sub_df[f].values, sub_df[self.labels_col].values)
+                m1 = maxmin(sub_df[f].values, sub_df[self.target_col].values)
+                m2 = minmax(sub_df[f].values, sub_df[self.target_col].values)
                 do = (m2 - sub_df[f]) / (m2 - m1)
                 dot[f] = dot[f].add(1 / (1 + abs(0.5 - do)), fill_value=0)
 
