@@ -1,6 +1,7 @@
+from copy import deepcopy
 from dataclasses import asdict, dataclass, field, fields
 from pathlib import Path
-from typing import Union, List
+from typing import Dict, Union, List
 
 
 @dataclass
@@ -12,7 +13,7 @@ class GeneralConfig:
     target_col: str = None
     seed: int = 0
 
-    def get_path_fields(self):
+    def get_path_fields(self) -> Dict[str, Union[str, Path]]:
         return {'rootdir': self.rootdir, 'datafile': self.datafile, 'matildadir': self.matildadir}
 
     def set(self, name, value):
@@ -73,13 +74,16 @@ class Configurations:
     def to_dict(self) -> dict:
         return asdict(self)
 
+    def copy(self):
+        return deepcopy(self)
 
-def from_dict(d: dict):
+
+def from_dict(d: dict) -> Configurations:
     config_sections = {f.name: f.type(**d[f.name]) for f in fields(Configurations)}
     return Configurations(**config_sections)
 
 
-def from_old_format(d_old: dict):
+def from_old_format(d_old: dict) -> Configurations:
     """
     Convenient method to map old configuration file fields into expected ones. It will be deprecated in future.
     """
