@@ -10,10 +10,65 @@ http://featureselection.asu.edu/
 Copyright (c) 2020 Jundong Li
 """
 
+from typing import Dict
+
 import numpy as np
+from sklearn.base import BaseEstimator, TransformerMixin
+from sklearn.utils.validation import (
+    check_X_y,
+    check_array,
+    check_is_fitted,
+    as_float_array
+)
+
 from . import entropy_estimators as ee
 
 
+class ITFS(TransformerMixin, BaseEstimator):
+    """
+    Information Theoretic Feature Selection.
+
+    :param str criteria: the scoring criteria
+    :param int n_features_to_select: if not None (default), selects exactly this number of features
+    :param dict parameters: optional parameters dependent on the chosen method
+    :param bool standardize: present just for compatibility
+    :param int n_jobs: present just for compatibility
+    """
+
+    def __init__(self, criteria: str = 'mrmr', n_features_to_select: int = None, parameters: Dict[str, float] = None,
+                 standardize: bool = None, n_jobs: int = 1):
+        if criteria.lower() not in globals():
+            raise ValueError(f"Unknown method '{criteria}'.")
+        self.criteria = criteria.lower()
+        self.n_features_to_select = n_features_to_select
+        self.params = dict() if parameters is None else parameters
+        self.standardize = standardize
+        self.n_jobs = n_jobs
+
+    def fit(self, X, y):
+        X_, y_ = check_X_y(X, y, accept_sparse=False, y_numeric=True)
+        F, J, MIfy = globals().get(self.criteria)(
+            X=X_,
+            y=y_,
+            n_selected_features=self.n_features_to_select,
+            **self.params
+        )
+        support = np.zeros(X_.shape[1], dtype=bool)
+        support[F] = True
+        self.support_ = support
+        self.n_features_ = support.sum()
+        self.weights_ = J
+
+        return self
+
+    def transform(self, X) -> np.ndarray:
+        check_is_fitted(self, ['weights_', 'support_', 'n_features_'])
+        X_ = check_array(X)
+        X_ = as_float_array(X_)
+        assert X_.shape[1] == len(self.support_)
+        return X_[:, self.support_]
+
+
 def lcsi(X, y, **kwargs):
     """
     This function implements the basic scoring criteria for linear combination of shannon information term.
@@ -116,7 +171,7 @@ def lcsi(X, y, **kwargs):
                 t2[i] += ee.mi(f_select, f)
                 t3[i] += ee.cmi(f_select, f, y)
                 # calculate j_cmi for feature i (not in F)
-                t = t1[i] - beta*t2[i] + gamma*t3[i]
+                t = t1[i] - beta * t2[i] + gamma * t3[i]
                 # record the largest j_cmi and the corresponding feature index
                 if t > j_cmi:
                     j_cmi = t
@@ -562,8 +617,8 @@ def icap(X, y, **kwargs):
                 f = X[:, i]
                 t2 = ee.mi(f_select, f)
                 t3 = ee.cmi(f_select, f, y)
-                if t2-t3 > vmax[i]:
-                    vmax[i] = t2-t3
+                if t2 - t3 > vmax[i]:
+                    vmax[i] = t2 - t3
                 # calculate j_icap for feature i (not in F)
                 t = t1[i] - vmax[i]
                 # record the largest j_icap and the corresponding feature index
