@@ -23,6 +23,14 @@ def load_yaml_file(path):
         traceback.print_exc()
 
 
+def write_yaml_file(data, path):
+    with open(path, 'w') as file:
+        try:
+            return yaml.dump(data, file, default_flow_style=False)
+        except yaml.YAMLError:
+            traceback.print_exc()
+
+
 def get_param_names(method):
     assert callable(method)
     sig = inspect.signature(method)
@@ -89,3 +97,18 @@ def check_dtype_consistency(s: pd.Series, expected_type: str) -> bool:
         elif is_integer_dtype(s):
             warnings.warn("")
     return True
+
+
+def pretty_time_delta(seconds):
+    seconds = int(seconds)
+    days, seconds = divmod(seconds, 86400)
+    hours, seconds = divmod(seconds, 3600)
+    minutes, seconds = divmod(seconds, 60)
+    if days > 0:
+        return '%dd%dh%dm%ds' % (days, hours, minutes, seconds)
+    elif hours > 0:
+        return '%dh%dm%ds' % (hours, minutes, seconds)
+    elif minutes > 0:
+        return '%dm%ds' % (minutes, seconds)
+    else:
+        return '%ds' % (seconds,)
